@@ -4,8 +4,11 @@ from splitiorequests.schemas.splits import tag_schema, traffic_type_schema
 
 
 class SplitSchema(Schema):
+    class Meta:
+        ordered = True
+
     name = fields.Str(required=True)
-    description = fields.Str()
+    description = fields.Str(missing=None)
     trafficType = fields.Nested(traffic_type_schema.TrafficTypeSchema)
     creationTime = fields.Integer()
     tags = fields.List(fields.Nested(tag_schema.TagSchema), missing=None)
@@ -17,6 +20,6 @@ class SplitSchema(Schema):
     @post_dump
     def clean_empty(self, data, **kwargs):
         new_data = data.copy()
-        for field_key in (key for key in data if data[key] is None and key != 'tags'):
+        for field_key in (key for key in data if key != 'tags' and key != 'description' and data[key] is None):
             del new_data[field_key]
-        return new_data
+        return dict(new_data)
