@@ -1,11 +1,18 @@
-from marshmallow import Schema, fields, post_load
+from marshmallow import Schema, fields, post_load, post_dump
 from splitiorequests.models.splits.traffic_type import TrafficType
 
 
 class TrafficTypeSchema(Schema):
+    class Meta:
+        ordered = True
+
     traffic_id = fields.Str(required=True, data_key='id')
     name = fields.Str(required=True)
 
     @post_load
     def load_traffic_type(self, data, **kwargs):
         return TrafficType(**data)
+
+    @post_dump
+    def convert_to_dict(self, data, **kwargs):
+        return dict(data)
